pub enum TemplatePlacementClip {
CenterChunk,
CenterChunkExpandedToTemplate,
CenterChunkContainsTemplateCenterExpandedToTemplate,
}Expand description
Vanilla bounding box adjustment before calling StructureTemplate.placeInWorld.
Variants
CenterChunk
Use the center chunk’s writable box unchanged.
CenterChunkExpandedToTemplate
Expand the center chunk writable box to include this piece’s transformed template box.
CenterChunkContainsTemplateCenterExpandedToTemplate
Expand to the transformed template box only when its center is in the center chunk.